#!/bin/bash
set -o errexit -o nounset -o pipefail
which shellcheck > /dev/null && shellcheck "$0"

NDKS="android crystax"
ABIS="x86 armeabi-v7a"
COMPILERS="4.8 4.9 clang3.5 clang3.6"
STLS="gnustl libcxx"

function arch_for_abi {
	case $1 in
	x86)
		echo x86
		;;
	armeabi-v7a)
		echo arm-linux-androideabi
		;;
	*)
		echo "Unkown abi: $1"
		exit 1
	esac
}

function libdir_for_abi {
	case $1 in
	x86)
		echo .
		;;
	armeabi-v7a)
		echo armv7-a
		;;
	*)
		echo "Unkown abi: $1"
		exit 1
	esac
}

function target_for_abi {
	case $1 in
	x86)
		echo i686-linux-android
		;;
	armeabi-v7a)
		echo arm-linux-androideabi
		;;
	*)
		echo "Unknown abi: $1"
		exit 1
	esac
}

for NDK in $NDKS; do
	for ABI in $ABIS; do
		LIBPATH="$(arch_for_abi "$ABI")/lib/$(libdir_for_abi "$ABI")"
		for COMPILER in $COMPILERS; do
			for STL in $STLS; do
				IDENT="$NDK-$ABI-$COMPILER-$STL"
				BASEPATH="$(realpath "$IDENT")"
				echo
				echo "Compiler: $BASEPATH"
				echo "Libpath: $LIBPATH"

				"$BASEPATH/bin/$(target_for_abi "$ABI")-c++" \
					--sysroot "$BASEPATH/sysroot" \
					-L"$BASEPATH/$LIBPATH" \
					-pie -fPIE \
					minimal.cpp -o "minimal-$IDENT"
			done
		done
	done
done

