#!/bin/bash
set -o errexit -o nounset -o pipefail
which shellcheck > /dev/null && shellcheck "$0"

NDKS="android crystax"
ABIS="x86 armeabi-v7a"
COMPILERS="4.8 4.9 clang3.5 clang3.6"
STLS="gnustl libcxx"

function arch_for_abi {
	case $1 in
	x86)
		echo x86
		;;
	armeabi-v7a)
		echo arm-linux-androideabi
		;;
	*)
		echo "Unkown arch: $1"
		exit 1
	esac
}

for NDK in $NDKS; do
	for ABI in $ABIS; do
		for COMPILER in $COMPILERS; do
			for STL in $STLS; do
				"/opt/$NDK-ndk/build/tools/make-standalone-toolchain.sh" \
					--toolchain="$(arch_for_abi "$ABI")-$COMPILER" \
					--abis="$ABI" \
					--stl="$STL" \
					--platform=android-15 \
					--install-dir="$NDK-$ABI-$COMPILER-$STL"
			done
		done
	done
done

